# 
# branches.sh - print a list of branches in an archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "list the branches in an archive category\\n"
                printf "usage: branches [options] [category]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
		printf " --full                        print the full names including the archive\\n"
                printf "\\n"
                printf "Print a list of branches within CATEGORY.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
full=

while test $# -ne 0 ; do

  case "$1" in 

    --full)             shift
	                full="--full"
			;;

    -*)                        printf "branches: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    "")                 shift
	                ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: branches [options] [category]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -ne 0 ; then
  cat="$1"
  shift
else
  cat=
fi

################################################################
# Sanity Check and Process Defaults
# 

if test -z "$cat" ; then
  cat="`arx tree-version .`"
fi

arx valid-package-name -b -- "$cat"
archive="`arx parse-package-name --arch \"$cat\"`"
category="`arx parse-package-name --basename \"$cat\"`"


################################################################
# Establish an Archive Connection
# 

if test "$WITHARCHIVE" != "$archive" ; then
  exec arx with-archive -A "$archive" arx branches "$full" "$archive/$category"
fi



################################################################
# Print the List
# 

basere="([a-zA-Z]([a-zA-Z0-9]*(-[a-zA-Z0-9]+)?)*)"

wftp-home
wftp-cd "$category"
branches=`wftp-ls | grep -E "^($basere)(--$basere)?$" | sort`

for branch in $branches ; do
  if test -n "$full" ; then
    printf "%s/%s\\n" $archive $branch
  else
    printf "%s\\n" $branch
  fi
done
