# 
# categories.sh - print a list of categories in an archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "list the categories in an archive\\n"
                printf "usage: categories [options]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
		printf " --full                        print the full names including the archive\\n"
                printf "\\n"
                printf "Print a list of categories within an archive.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
full=

while test $# -ne 0 ; do

  case "$1" in 

    --full)             shift
	                full="--full"
			;;

    -*)                        printf "categories: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    "")                  shift
	                ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: categories [options] archive\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

################################################################
# Sanity Check and Process Defaults
# 

if test $# -eq 1 ; then
  archive="$1"
else
  archive=`arx my-default-archive -e "categories"`
fi

################################################################
# Establish an Archive Connection
# 

if test "$WITHARCHIVE" != "$archive" ; then
  exec arx with-archive -A "$archive" arx categories "$full" "$archive"
fi


################################################################
# Print the List
# 

wftp-home
categories=`wftp-ls | sed -e "s/
//" | grep -E "^[a-zA-Z]([a-zA-Z0-9]*(-[a-zA-Z0-9]+)?)*$" | sort`

for cat in $categories ; do
  if test -n "$full" ; then
    printf "%s/%s\\n" $archive $cat
  else
    printf "%s\\n" $cat
  fi
done

