# copy-from-library.sh: try to copy a revision from the library
# 
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
# of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

command_line="$*"

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "try to copy a revision from the library\\n"
                printf "usage: copy-from-library [options] revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --silent                      no output\\n"
                printf " --quiet                       only output errors\\n"
                printf " --default-output              default output\\n"
                printf " --report                      slightly verbose output\\n"
                printf " --verbose                     maximal output\\n"
                printf " --debug                       debugging output\\n"
                printf "\\n"
                printf "Look for a library copy of REVISION.  If one is found,\\n"
                printf "copy it to the current directory and exit with status 0.,\\n"
                printf "Otherwise exit with status 1.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=


silent=1
quiet=2
default_output=3
report=4
verbose=5

verbosity=$default_output
verbose_opt=

debug_opt=

while test $# -ne 0 ; do

  case "$1" in 

    --silent)           shift
                        verbosity=$silent
                        verbose_opt=--silent
                        ;;

    --quiet)            shift
                        verbosity=$quiet
                        verbose_opt=--quiet
                        ;;

    --default-output)   shift
                        verbosity=$default_output
                        verbose_opt=--default-output
                        ;;

    --report)           shift
                        verbosity=$report
                        verbose_opt=--report
                        ;;

    --verbose)          shift
                        verbosity=$verbose
                        verbose_opt=--verbose
                        ;;

    --debug)        shift
                    arx heading "copy-from-library: debugging output enabled\\n"
                    set -x
                ;;

    --)                        shift
                        break
                        ;;

    -*)                        printf "copy-from-library: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: copy-from-library [options] revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

revision="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

tree_location="`arx library-find \"$revision\" 2> /dev/null`"

# This point only reached if the revision is in the library.
# 

here="`pwd`"

################################################################
# Greetings
# 
#  This is an internal command.

if test $verbosity -ge $report ; then
  ARCH__OUTLINE_DEPTH="$ARCH__OUTLINE_DEPTH*"
  arx heading "copy-from-library\\n"
  printf "arguments: %s\\n" "$command_line" | fold -w 60 | arx body-indent
  if test $verbosity -ge $verbose ; then
    arx heading --sub "copy-from-library start time: %s\\n" "`date`"
    arx heading --sub "copying from: %s\\n" "$tree_location"
    arx heading --sub "copying to: %s\\n" "$here"
  fi
fi

################################################################
# Copy It
# 


if test $verbosity -ge $report ; then
  arx heading --sub "copying revision from library\\n" 
  arx heading --sub --sub "dir: %s\\n" "$tree_location"
fi

cat "$tree_location/,,index" \
| cut -f 1 \
| copy-file-list -- - "$tree_location" "$here"

if test $verbosity -ge $verbose ; then
  arx heading --sub "copy-from-library finish time: %s\\n" "`date`"
fi


# tag: Tom Lord Thu Jan 24 19:57:10 2002 (library/copy-from-library.sh)
#
