# vim: set expandtab shiftwidth=2 softtabstop=2:
#
# my-editor.sh - the user's editor
#
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002 Alexander Deruwe
# Copyright (C) 2003 Walter Landry and the Regents
#                    of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then
  for opt in "$@" ; do
    case $opt in
      --version|-V)
          exec arx --version
          ;;


      --help|-h)
          printf "print or change your default arch editor\\n"
          printf "usage: my-editor [options] editor-string\\n"
          printf "\\n"
          printf " -V --version                  print version info\\n"
          printf " -h --help                     display help\\n"
          printf "\\n"
          printf " -v --verbose                  print a reassuring message\\n"
          printf "\\n"
          printf "With no argument print your default arch editor.\\n"
          printf "\\n"
          printf "With an argument, record EDITOR-STRING as your editor\\n"
          printf "in ~/.arch-params/=editor\\n"
          printf "\\n"
          exit 0
          ;;

      *)
          ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 

verbose=0
type=

while test $# -ne 0 ; do
  case "$1" in 
    -v|--verbose)
        shift
        verbose=1
        ;;

    -*)
        printf "my-editor: unrecognized option (%s)\\n" "$1" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
        ;;

    *)
        break
        ;;
  esac
done



################################################################
# Ordinary Arguments
# 

case $# in 
  0)
      type=print
      ;;

  1)
      type=set
      editor="$1"

      # If the new editor is an empty string,
      # then just print the current one
      if test -z "$editor" ; then
        type=print
      else
        set +e
        editorpath=`which "$editor"`
        set -e
      fi
      ;;

  *)
      if test $# -gt 1 ; then
        printf "usage: my-editor [options] [id-string]\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      ;;
esac


################################################################
# Sanity Check
#

if test $type = "set" ; then
  if test -z "$editorpath" ; then
    printf "my-editor: invalid editor (%s)\\n" "$editor" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
  fi
fi


################################################################
# Do It
# 

editorfile="=editor"
archparamsdir=~/.arch-params

mkdir -p "$archparamsdir"
case $type in
  set)
      printf "%s\\n" "$editorpath" > "$archparamsdir/$editorfile"
      if test $verbose -ne 0 ; then
        printf "editor path set (%s)\\n" "$editorpath"
      fi
      ;;

  print)
      if test ! -e "$archparamsdir/$editorfile" ; then
        printf "my-editor: no editor path set!\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      printf "%s\\n" "`cat $archparamsdir/$editorfile`"
      ;;
esac

exit 0
