# vim: set expandtab shiftwidth=2 softtabstop=2:
#
# my-guidiff.sh - the user's guidiff
#
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002 Alexander Deruwe
# Copyright (C) 2003 Walter Landry and the Regents
#                    of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then
  for opt in "$@" ; do
    case $opt in
      --version|-V)
          exec arx --version
          ;;


      --help|-h)
          printf "print or change your default arch guidiff\\n"
          printf "usage: my-guidiff [options] guidiff-string\\n"
          printf "\\n"
          printf " -V --version                  print version info\\n"
          printf " -h --help                     display help\\n"
          printf "\\n"
          printf " -v --verbose                  print a reassuring message\\n"
          printf "\\n"
          printf "With no argument print your default arch guidiff.\\n"
          printf "\\n"
          printf "With an argument, record GUIDIFF-STRING as your guidiff\\n"
          printf "in ~/.arch-params/=guidiff\\n"
          printf "\\n"
          exit 0
          ;;

      *)
          ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 

verbose=0
type=

while test $# -ne 0 ; do
  case "$1" in 
    -v|--verbose)
        shift
        verbose=1
        ;;

    -*)
        printf "my-guidiff: unrecognized option (%s)\\n" "$1" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
        ;;

    *)
        break
        ;;
  esac
done



################################################################
# Ordinary Arguments
# 

case $# in 
  0)
      type=print
      ;;

  1)
      type=set
      guidiff="$1"

      # If the new guidiff is an empty string,
      # then just print the current one
      if test -z "$guidiff" ; then
        type=print
      else
        set +e
        guidiffpath=`which "$guidiff"`
        set -e
      fi
      ;;

  *)
      if test $# -gt 1 ; then
        printf "usage: my-guidiff [options] [id-string]\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      ;;
esac


################################################################
# Sanity Check
#

if test $type = "set" ; then
  if test -z "$guidiffpath" ; then
    printf "my-guidiff: invalid guidiff (%s)\\n" "$guidiff" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
  fi
fi


################################################################
# Do It
# 

guidifffile="=gui-diff"
archparamsdir=~/.arch-params

mkdir -p "$archparamsdir"
case $type in
  set)
      printf "%s\\n" "$guidiffpath" > "$archparamsdir/$guidifffile"
      if test $verbose -ne 0 ; then
        printf "guidiff path set (%s)\\n" "$guidiffpath"
      fi
      ;;

  print)
      if test ! -e "$archparamsdir/$guidifffile" ; then
        printf "my-guidiff: no guidiff path set!\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      printf "%s\\n" "`cat $archparamsdir/$guidifffile`"
      ;;
esac

exit 0
