// 
// mkpatch-file-filter utility
//
// Copyright (C) 2002 Karel Gardas
// Minor Bug fix 2003 Walter Landry & the Regents of the University of California
//
// See the file "COPYING" for further information about
// the copyright and warranty status of this work.
// 

#include <iostream>
#include <string>
#include <fstream>
#include <vector>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <assert.h>

using namespace std;

bool
same_files(const char* f1, const char* f2)
{
    ifstream stream1(f1, ios::in);
    ifstream stream2(f2, ios::in);
    vector<char> buf1(65535);
    vector<char> buf2(65535);
    while(stream1.good() && stream2.good()) {
	stream1.read(&buf1[0], 65535);
	stream2.read(&buf2[0], 65535);
	if (stream1.gcount() != stream2.gcount()) {
	    //cerr << "files differ => output" << endl;
	    return false;
	}
	for (int i=0; i<stream1.gcount(); i++) {
	    if (buf1[i] != buf2[i]) {
		//cerr << "files differ2 => output" << endl;
		return false;
	    }
	}
    }
    //cerr << "same files" << endl;
    return true;
}

int
main(int argc, char* argv[])
{
    assert(argc == 4);
    string original = argv[1];
    string modified = argv[2];
    string files = argv[3];
    //cerr << argv[0] << " " << original << " " << modified << " " << files << endl;
    ifstream fin;
    fin.open(files.c_str(), ios::in);
    string orig_file;
    string mod_file;
    while (fin >> orig_file
	   && fin >> mod_file
	   && fin.good()) {
	//cerr << orig_file << " <-> " << mod_file << endl;
	struct stat st1;
	struct stat st2;
	int x = lstat((original + "/" + orig_file).c_str(), &st1);
	//cerr << "x1: " << x << endl;
	x = lstat((modified + "/" + mod_file).c_str(), &st2);
	//cerr << "x2: " << x << endl;
	if (S_ISLNK(st1.st_mode)) {
	    //cerr << orig_file << " is link => output" << endl;
	    cout << orig_file << " " << mod_file << endl;
	    continue;
	}
	if (S_ISLNK(st2.st_mode)) {
	    //cerr << mod_file << " is link => output" << endl;
	    cout << orig_file << " " << mod_file << endl;
	    continue;
	}
	if (st1.st_mode != st2.st_mode) {
	    //cerr << "permissions are different => output" << endl;
	    cout << orig_file << " " << mod_file << endl;
	    continue;
	}
	// regular files
	if (!same_files((original + "/" + orig_file).c_str(), (modified + "/" + mod_file).c_str())) {
	    cout << orig_file << " " << mod_file << endl;
	}	    
    }
    return 0;
}
