;; Prepares a new source tree for branching and then calls arx-log-mode.

;; Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
;; of California

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(put 'arx-create-branch-error
     'error-conditions
     '(error arx-error arx-create-branch-error))

(put 'arx-create-branch-error 'error-message "arx-create-branch failed")


(defun arx-create-branch (old new new-directory)
  "Prepare a new branch and edit the log file."
  (interactive 
   (list (completing-read "Old Version: " 'arx-complete-versions)
	 (completing-read "New Version: " 'arx-complete-versions)
	 (read-file-name "Directory for new branch: "
				     default-directory default-directory)))
  (save-current-buffer
    (set-buffer (get-buffer-create "*arx*"))
    (erase-buffer))
  (if (= 0 (call-process "arx" nil "*arx*" t "create-branch"
			 "--non-interactive"
			 old new (expand-file-name new-directory)))
      (progn
	(cd (expand-file-name new-directory))
	(find-file (car (save-current-buffer
			  (set-buffer "*arx*")
			  (split-string (buffer-string) "\n"))))
	(arx-log-mode)
	(end-of-line)
	(let* ((name-list (arx-split-names new)))
	  (set (make-local-variable 'arx-new-version) new)
	  (set (make-local-variable 'arx-new-category) (car name-list))
	  (set (make-local-variable 'arx-new-branch)
	       (concat arx-new-category "--" (nth 1 name-list)))))
    (progn
      (display-buffer "*arx*" t)
      (signal 'arx-create-branch-error (list old new new-directory)))))
